@@ -712,6 +712,10 @@ sub regenerate_readme_md {
                 } elsif ($service_name =~ m!^github-actions(?:/(.+))?$!) {
                     my $workflow_name = $1 || 'test';
                     push @badges, "[![Actions Status](https://github.com/$user_name/$repository_name/workflows/$workflow_name/badge.svg)](https://github.com/$user_name/$repository_name/actions)";
+                } elsif ($service_name eq 'gitlab-pipeline') {
+                    push @badges, "[![Gitlab pipeline](https://gitlab.com/$user_name/$repository_name/badges/master/pipeline.svg)](https://gitlab.com/$user_name/$repository_name/-/commits/master)";
+                } elsif ($service_name eq 'gitlab-coverage') {
+                    push @badges, "[![Gitlab coverage](https://gitlab.com/$user_name/$repository_name/badges/master/coverage.svg)](https://gitlab.com/$user_name/$repository_name/-/commits/master)";
                 }
             }
         }
